summaryrefslogtreecommitdiffstats
path: root/bsps/arm/stm32h7/include/stm32h7xx_hal_rng_ex.h
diff options
context:
space:
mode:
Diffstat (limited to 'bsps/arm/stm32h7/include/stm32h7xx_hal_rng_ex.h')
-rw-r--r--bsps/arm/stm32h7/include/stm32h7xx_hal_rng_ex.h67
1 files changed, 37 insertions, 30 deletions
diff --git a/bsps/arm/stm32h7/include/stm32h7xx_hal_rng_ex.h b/bsps/arm/stm32h7/include/stm32h7xx_hal_rng_ex.h
index ea22a00443..65797e6887 100644
--- a/bsps/arm/stm32h7/include/stm32h7xx_hal_rng_ex.h
+++ b/bsps/arm/stm32h7/include/stm32h7xx_hal_rng_ex.h
@@ -6,13 +6,12 @@
******************************************************************************
* @attention
*
- * <h2><center>&copy; Copyright (c) 2017 STMicroelectronics.
- * All rights reserved.</center></h2>
+ * Copyright (c) 2017 STMicroelectronics.
+ * All rights reserved.
*
- * This software component is licensed by ST under BSD 3-Clause license,
- * the "License"; You may not use this file except in compliance with the
- * License. You may obtain a copy of the License at:
- * opensource.org/licenses/BSD-3-Clause
+ * This software is licensed under terms that can be found in the LICENSE file
+ * in the root directory of this software component.
+ * If no LICENSE file comes with this software, it is provided AS-IS.
*
******************************************************************************
*/
@@ -32,24 +31,24 @@ extern "C" {
* @{
*/
-#if defined (RNG)
-#if defined (RNG_CR_CONDRST)
+#if defined(RNG)
+#if defined(RNG_CR_CONDRST)
-/** @defgroup RNGEx RNGEx
+/** @defgroup RNG_Ex RNG_Ex
* @ingroup RTEMSBSPsARMSTM32H7
* @brief RNG Extension HAL module driver
* @{
*/
/* Exported types ------------------------------------------------------------*/
-/** @defgroup RNGEx_Exported_Types RNGEx Exported Types
+/** @defgroup RNG_Ex_Exported_Types RNG_Ex Exported Types
* @ingroup RTEMSBSPsARMSTM32H7
- * @brief RNGEx Exported types
+ * @brief RNG_Ex Exported types
* @{
*/
/**
* @brief RNGEX Configuration Structure definition
*/
typedef struct
@@ -58,9 +57,9 @@ typedef struct
uint32_t Config2; /*!< Config2 must be a value between 0 and 0x7 */
uint32_t Config3; /*!< Config3 must be a value between 0 and 0xF */
uint32_t ClockDivider; /*!< Clock Divider factor.This parameter can
- be a value of @ref RNGEX_Clock_Divider_Factor */
+ be a value of @ref RNG_Ex_Clock_Divider_Factor */
uint32_t NistCompliance; /*!< NIST compliance.This parameter can be a
- value of @ref RNGEX_NIST_Compliance */
+ value of @ref RNG_Ex_NIST_Compliance */
} RNG_ConfigTypeDef;
/**
@@ -68,14 +67,14 @@ typedef struct
*/
/* Exported constants --------------------------------------------------------*/
-/** @defgroup RNGEX_Exported_Constants RNGEX Exported Constants
+/** @defgroup RNG_Ex_Exported_Constants RNG_Ex Exported Constants
* @ingroup RTEMSBSPsARMSTM32H7
* @{
*/
/** @defgroup RNGEX_Clock_Divider_Factor Value used to configure an internal
* @ingroup RTEMSBSPsARMSTM32H7
- * programmable divider acting on the incoming RNG clock
+ * programmable divider acting on the incoming RNG clock
* @{
*/
#define RNG_CLKDIV_BY_1 (0x00000000UL) /*!< No clock division */
@@ -113,7 +112,7 @@ typedef struct
* @}
*/
/** @defgroup RNGEX_NIST_Compliance NIST Compliance configuration
* @ingroup RTEMSBSPsARMSTM32H7
* @{
*/
@@ -129,7 +128,7 @@ typedef struct
*/
/* Private types -------------------------------------------------------------*/
-/** @defgroup RNGEx_Private_Types RNGEx Private Types
+/** @defgroup RNG_Ex_Private_Types RNG_Ex Private Types
* @ingroup RTEMSBSPsARMSTM32H7
* @{
*/
@@ -139,7 +138,7 @@ typedef struct
*/
/* Private variables ---------------------------------------------------------*/
-/** @defgroup RNGEx_Private_Variables RNGEx Private Variables
+/** @defgroup RNG_Ex_Private_Variables RNG_Ex Private Variables
* @ingroup RTEMSBSPsARMSTM32H7
* @{
*/
@@ -149,7 +148,7 @@ typedef struct
*/
/* Private constants ---------------------------------------------------------*/
-/** @defgroup RNGEx_Private_Constants RNGEx Private Constants
+/** @defgroup RNG_Ex_Private_Constants RNG_Ex Private Constants
* @ingroup RTEMSBSPsARMSTM32H7
* @{
*/
@@ -159,7 +158,7 @@ typedef struct
*/
/* Private macros ------------------------------------------------------------*/
-/** @defgroup RNGEx_Private_Macros RNGEx Private Macros
+/** @defgroup RNG_Ex_Private_Macros RNG_Ex Private Macros
* @ingroup RTEMSBSPsARMSTM32H7
* @{
*/
@@ -193,11 +192,11 @@ typedef struct
/**
- * @}
- */
+ * @}
+ */
/* Private functions ---------------------------------------------------------*/
-/** @defgroup RNGEx_Private_Functions RNGEx Private Functions
+/** @defgroup RNG_Ex_Private_Functions RNG_Ex Private Functions
* @ingroup RTEMSBSPsARMSTM32H7
* @{
*/
@@ -207,12 +206,12 @@ typedef struct
*/
/* Exported functions --------------------------------------------------------*/
-/** @defgroup RNGEx_Exported_Functions RNGEx Exported Functions
+/** @defgroup RNG_Ex_Exported_Functions RNG_Ex Exported Functions
* @ingroup RTEMSBSPsARMSTM32H7
* @{
*/
-/** @addtogroup RNGEx_Exported_Functions_Group1
+/** @addtogroup RNG_Ex_Exported_Functions_Group1
* @{
*/
HAL_StatusTypeDef HAL_RNGEx_SetConfig(RNG_HandleTypeDef *hrng, RNG_ConfigTypeDef *pConf);
@@ -223,6 +222,15 @@ HAL_StatusTypeDef HAL_RNGEx_LockConfig(RNG_HandleTypeDef *hrng);
* @}
*/
+/** @addtogroup RNG_Ex_Exported_Functions_Group2
+ * @{
+ */
+HAL_StatusTypeDef HAL_RNGEx_RecoverSeedError(RNG_HandleTypeDef *hrng);
+
+/**
+ * @}
+ */
+
/**
* @}
*/
@@ -235,7 +243,7 @@ HAL_StatusTypeDef HAL_RNGEx_LockConfig(RNG_HandleTypeDef *hrng);
* @}
*/
-#endif /* CONDRST */
+#endif /* RNG_CR_CONDRST */
#endif /* RNG */
/**
@@ -247,6 +255,5 @@ HAL_StatusTypeDef HAL_RNGEx_LockConfig(RNG_HandleTypeDef *hrng);
#endif
-#endif /* STM32H7xx_HAL_RNGEX_H */
+#endif /* STM32H7xx_HAL_RNG_EX_H */
-/************************ (C) COPYRIGHT STMicroelectronics *****END OF FILE****/
@@ -32,24 +31,24 @@ extern "C" {
*/
/**
- * @brief RNGEX Configuration Structure definition
+ * @brief RNG_Ex Configuration Structure definition
*/
typedef struct
@@ -68,14 +67,14 @@ typedef struct
* @{
*/
-/** @defgroup RNGEX_Clock_Divider_Factor Value used to configure an internal
+/** @defgroup RNG_Ex_Clock_Divider_Factor Value used to configure an internal
* @ingroup RTEMSBSPsARMSTM32H7
@@ -113,7 +112,7 @@ typedef struct
* @}
*/
-/** @defgroup RNGEX_NIST_Compliance NIST Compliance configuration
+/** @defgroup RNG_Ex_NIST_Compliance NIST Compliance configuration
* @ingroup RTEMSBSPsARMSTM32H7
* @{